@@ -4,11 +4,8 @@ from netbox_storage.api.views import (
     NetboxStorageRootView,
     DriveViewSet,
     FilesystemViewSet,
-    LogicalVolumeViewSet,
     PartitionViewSet,
-    PhysicalVolumeViewSet,
-    VolumeGroupViewSet,
-    LinuxVolumeViewSet
+    LinuxVolumeViewSet,
 )
 
 router = NetBoxRouter()
@@ -16,10 +13,7 @@ router.APIRootView = NetboxStorageRootView
 
 router.register("drive", DriveViewSet)
 router.register("filesystem", FilesystemViewSet)
-router.register("logicalvolume", LogicalVolumeViewSet)
 router.register("partition", PartitionViewSet)
-router.register("physicalvolume", PhysicalVolumeViewSet)
-router.register("volumegroup", VolumeGroupViewSet)
 router.register("linuxvolume", LinuxVolumeViewSet)
 
 urlpatterns = router.urls
