@@ -10,13 +10,12 @@ from netbox.forms import (
     NetBoxModelImportForm,
     NetBoxModelForm,
 )
+from netbox_storage.models import Drive, StorageConfiguration
 from utilities.forms import (
     CSVModelChoiceField,
     DynamicModelChoiceField,
 )
-
-from netbox_storage.models import Drive, StorageConfiguration
-from virtualization.models import Cluster, ClusterType, VirtualMachine
+from virtualization.models import Cluster, ClusterType
 
 
 class DriveForm(NetBoxModelForm):
@@ -38,10 +37,6 @@ class DriveForm(NetBoxModelForm):
         },
         help_text="The Storage Cluster of the drive",
     )
-    storage_configuration = DynamicModelChoiceField(
-        queryset=StorageConfiguration.objects.all(),
-        help_text="Mapping between drive and virtual machine  e.g. vm-testinstall-01",
-    )
     description = CharField(
         required=False,
         label="Description",
@@ -60,7 +55,6 @@ class DriveForm(NetBoxModelForm):
             "Drive Configuration",
             (
                 "size",
-                "storage_configuration",
                 "description",
             ),
         ),
@@ -72,7 +66,6 @@ class DriveForm(NetBoxModelForm):
         fields = (
             "size",
             "cluster",
-            "storage_configuration",
             "description",
         )
 
@@ -92,10 +85,6 @@ class DriveFilterForm(NetBoxModelFilterSetForm):
         ),
         required=False,
     )
-    storage_configuration = DynamicModelChoiceField(
-        queryset=StorageConfiguration.objects.all(),
-        required=False
-    )
 
 
 class DriveImportForm(NetBoxModelImportForm):
@@ -105,12 +94,6 @@ class DriveImportForm(NetBoxModelImportForm):
         required=False,
         help_text='Assigned cluster'
     )
-    storage_configuration = CSVModelChoiceField(
-        queryset=StorageConfiguration.objects.all(),
-        required=False,
-        to_field_name='name',
-        help_text='Required'
-    )
 
     def __init__(self, *args, **kwargs):
         super().__init__(*args, **kwargs)
@@ -121,7 +104,6 @@ class DriveImportForm(NetBoxModelImportForm):
         fields = (
             "size",
             "cluster",
-            "storage_configuration",
             "description",
         )
 
@@ -140,18 +122,12 @@ class DriveBulkEditForm(NetBoxModelBulkEditForm):
             'site_id': '$site'
         }
     )
-    storage_configuration = CSVModelChoiceField(
-        queryset=StorageConfiguration.objects.all(),
-        required=False,
-        to_field_name='name',
-        help_text='Required'
-    )
     description = CharField(max_length=255, required=False)
 
     fieldsets = (
         (
             None,
-            ("size", "cluster", "storage_configuration", "description"),
+            ("size", "cluster", "description"),
         ),
     )
     nullable_fields = ["description"]
