@@ -22,15 +22,8 @@ from virtualization.models import VirtualMachine
 
 class LinuxVolumeForm(NetBoxModelForm):
     """Form for creating a new LinuxVolume object."""
-    storage_configuration = DynamicModelChoiceField(
-        queryset=StorageConfiguration.objects.all(),
-        required=False,
-    )
     drive = DynamicModelChoiceField(
         queryset=Drive.objects.all(),
-        query_params={
-            'storage_configuration_id': '$storage_configuration',
-        },
         help_text="The Storage Cluster of the drive",
     )
     partition = DynamicModelChoiceField(
@@ -66,7 +59,6 @@ class LinuxVolumeForm(NetBoxModelForm):
         model = LinuxVolume
 
         fields = (
-            "storage_configuration",
             "drive",
             "partition",
             "size",
@@ -81,14 +73,8 @@ class LinuxVolumeFilterForm(NetBoxModelFilterSetForm):
 
     model = LinuxVolume
 
-    storage_configuration = DynamicModelChoiceField(
-        queryset=VirtualMachine.objects.all(),
-    )
     drive = DynamicModelChoiceField(
         queryset=Drive.objects.all(),
-        query_params={
-            'storage_configuration_id': '$storage_configuration',
-        },
         help_text="The Storage Cluster of the drive",
     )
     partition = DynamicModelChoiceField(
