@@ -6,20 +6,14 @@ from django.forms import (
 from django.urls import reverse_lazy
 
 from netbox.forms import (
-    NetBoxModelBulkEditForm,
-    NetBoxModelFilterSetForm,
-    NetBoxModelImportForm,
     NetBoxModelForm,
 )
-from utilities.forms import (
-    CSVModelChoiceField,
-    DynamicModelChoiceField, APISelect,
-)
-
 from netbox_storage.models import Drive, Filesystem, Partition, PhysicalVolume, VolumeGroup, LogicalVolume, \
     StorageConfiguration
+from utilities.forms import (
+    DynamicModelChoiceField, APISelect,
+)
 from virtualization.models import Cluster, ClusterType, VirtualMachine
-import logging
 
 
 class LVMSimpleForm(NetBoxModelForm):
@@ -111,8 +105,7 @@ class LVMSimpleForm(NetBoxModelForm):
     def save(self, *args, **kwargs):
         storage_configuration = super().save(*args, **kwargs)
 
-        drive = Drive.objects.create(cluster=self.cleaned_data['cluster'], size=self.cleaned_data['size'],
-                                     storage_configuration=storage_configuration)
+        drive = Drive.objects.create(cluster=self.cleaned_data['cluster'], size=self.cleaned_data['size'])
         partition = Partition.objects.create(drive=drive, device=drive.device_name(), size=self.cleaned_data['size'],
                                              type='Linux LVM', description='Partition 1 on SSD Cluster')
         volumegroup = VolumeGroup.objects.create(vg_name=self.cleaned_data['vg_name'])
@@ -121,8 +114,101 @@ class LVMSimpleForm(NetBoxModelForm):
                                                      lv_name=self.cleaned_data['lv_name'],
                                                      size=self.cleaned_data['size'],
                                                      path=self.cleaned_data['path'],
-                                                     fs=self.cleaned_data['fs'],
-                                                     storage_configuration=self.cleaned_data['storage_configuration'])
+                                                     fs=self.cleaned_data['fs'])
+        print(f"{self.cleaned_data['lv_name']}")
+        print(f"{self.cleaned_data['vg_name']}")
+        print(f"{self.cleaned_data['size']}")
+        print(f"{self.cleaned_data['path']}")
+        print(f"{self.cleaned_data['fs']}")
+
+        print("Instances")
+        print(drive)
+        print(partition)
+        print(volumegroup)
+        print(physicalvolume)
+        print(logicalvolume)
+
+        return drive
+
+
+class LinuxVolumeSimpleForm(NetBoxModelForm):
+    size = FloatField(
+        label="Size (GB)",
+        help_text="The size of the logical volume e.g. 25",
+        validators=[MinValueValidator(0.1)],
+    )
+    path = CharField(
+        label="Path",
+        help_text="The mounted path of the volume e.g. /var/lib/docker",
+    )
+    fs = DynamicModelChoiceField(
+        queryset=Filesystem.objects.all(),
+        label="Filesystem Name",
+        widget=APISelect(
+            attrs={"data-url": reverse_lazy("plugins-api:netbox_storage-api:filesystem-list")}
+        ),
+        help_text="The Filesystem of the Volume e.g. ext4",
+    )
+    cluster_type = DynamicModelChoiceField(
+        queryset=ClusterType.objects.all(),
+        help_text="The Cluster Type of the drive",
+    )
+    cluster = DynamicModelChoiceField(
+        queryset=Cluster.objects.all(),
+        query_params={
+            'type_id': '$cluster_type'  # ClusterType.objects.filter(name="Storage").values_list('id', flat=True)[0]
+        },
+        help_text="The Storage Cluster of the drive",
+    )
+    virtual_machine = DynamicModelChoiceField(
+        queryset=VirtualMachine.objects.all(),
+        help_text="Mapping between drive and virtual machine  e.g. vm-testinstall-01",
+    )
+    description = CharField(
+        required=False,
+        label="Description",
+        help_text="Short Description e.g. Hard Drive 1 on SSD Cluster",
+    )
+
+    fieldsets = (
+        (
+            "Drive Cluster Config",
+            (
+                "cluster_type",
+                "cluster",
+                "virtual_machine",
+            ),
+        ),
+        (
+            "Linux Volume Configuration",
+            (
+                "size",
+                "path",
+                "fs",
+                "description",
+            ),
+        ),
+    )
+
+    class Meta:
+        model = StorageConfiguration
+        fields = [
+            "virtual_machine",
+        ]
+
+    def save(self, *args, **kwargs):
+        storage_configuration = super().save(*args, **kwargs)
+
+        drive = Drive.objects.create(cluster=self.cleaned_data['cluster'], size=self.cleaned_data['size'])
+        partition = Partition.objects.create(drive=drive, device=drive.device_name(), size=self.cleaned_data['size'],
+                                             type='Linux LVM', description='Partition 1 on SSD Cluster')
+        volumegroup = VolumeGroup.objects.create(vg_name=self.cleaned_data['vg_name'])
+        physicalvolume = PhysicalVolume.objects.create(partition=partition, pv_name=drive.device_name(), vg=volumegroup)
+        logicalvolume = LogicalVolume.objects.create(vg=volumegroup,
+                                                     lv_name=self.cleaned_data['lv_name'],
+                                                     size=self.cleaned_data['size'],
+                                                     path=self.cleaned_data['path'],
+                                                     fs=self.cleaned_data['fs'])
         print(f"{self.cleaned_data['lv_name']}")
         print(f"{self.cleaned_data['vg_name']}")
         print(f"{self.cleaned_data['size']}")
@@ -188,10 +274,6 @@ class VolumeSimpleForm(NetBoxModelForm):
         },
         help_text="The Storage Cluster of the drive",
     )
-    storage_configuration = DynamicModelChoiceField(
-        queryset=StorageConfiguration.objects.all(),
-        help_text="Mapping between drive and virtual machine  e.g. vm-testinstall-01",
-    )
     description = CharField(
         required=False,
         label="Description",
@@ -204,7 +286,6 @@ class VolumeSimpleForm(NetBoxModelForm):
         fields = (
             "size",
             "cluster",
-            "storage_configuration",
             "description",
         )
 
