@@ -43,10 +43,6 @@ class Migration(migrations.Migration):
                 ("cluster",
                  models.ForeignKey(on_delete=models.deletion.PROTECT, related_name="cluster_drive",
                                    to="virtualization.cluster")),
-                ("storage_configuration",
-                 models.ForeignKey(blank=True, null=True, on_delete=models.deletion.CASCADE,
-                                   related_name="storage_configuration_drive",
-                                   to="netbox_storage.storageconfiguration")),
                 ("size", models.FloatField()),
                 ("identifier", models.CharField(max_length=255)),
                 ("description", models.CharField(max_length=255)),
@@ -174,10 +170,6 @@ class Migration(migrations.Migration):
                                    to='netbox_storage.filesystem')),
                 ("size", models.FloatField()),
                 ("description", models.CharField(max_length=255)),
-                ("storage_configuration",
-                 models.ForeignKey(blank=True, null=True, on_delete=models.deletion.CASCADE,
-                                   related_name="storage_configuration_logical_volume",
-                                   to="netbox_storage.storageconfiguration")),
             ],
             options={
                 "ordering": ("lv_name", "id"),
@@ -206,10 +198,6 @@ class Migration(migrations.Migration):
                                    to='netbox_storage.filesystem')),
                 ("size", models.FloatField()),
                 ("description", models.CharField(max_length=255)),
-                ("storage_configuration",
-                 models.ForeignKey(blank=True, null=True, on_delete=models.deletion.CASCADE,
-                                   related_name="storage_configuration_linux_volume",
-                                   to="netbox_storage.storageconfiguration")),
             ],
             options={
                 "ordering": ("path", "fs", "id"),
