@@ -3,7 +3,6 @@ from django.db import models
 from django.db.models import Sum
 from django.urls import reverse
 
-from dcim.models import Platform
 from netbox.models import NetBoxModel
 
 
@@ -18,8 +17,11 @@ class StorageConfiguration(NetBoxModel):
         "virtual_machine"
     ]
 
+    class Meta:
+        ordering = ["virtual_machine"]
+
     def get_absolute_url(self):
-        return reverse("plugins:netbox_storage:linuxvolume", kwargs={"pk": self.pk})
+        return reverse("plugins:netbox_storage:storageconfiguration", kwargs={"pk": self.pk})
 
     def __str__(self):
         return f"Storage Configuration of the VM {self.virtual_machine}"
@@ -41,13 +43,8 @@ class Drive(NetBoxModel):
         max_length=255,
         blank=True,
     )
-    storage_configuration = models.ForeignKey(
-        StorageConfiguration,
-        on_delete=models.CASCADE,
-        related_name='storage_configuration_linux_volume',
-    )
 
-    clone_fields = ["cluster", "size", "identifier", "description", "storage_configuration"]
+    clone_fields = ["cluster", "size", "identifier", "description"]
 
     prerequisite_models = (
         'virtualization.Cluster',
@@ -66,7 +63,7 @@ class Drive(NetBoxModel):
     def save(self, *args, **kwargs):
         is_already_implemented = Drive.objects.filter(id=self.pk).count()
         if is_already_implemented == 0:
-            number_of_hard_drives = Drive.objects.filter(storage_configuration=self.storage_configuration).\
+            number_of_hard_drives = Drive.objects.all().\
                 order_by("created").count()
 
             self.identifier = f"Hard Drive {number_of_hard_drives + 1}"
@@ -289,11 +286,6 @@ class LogicalVolume(NetBoxModel):
         max_length=255,
         blank=True,
     )
-    storage_configuration = models.ForeignKey(
-        StorageConfiguration,
-        on_delete=models.CASCADE,
-        related_name='storage_configuration_logical_volume',
-    )
 
     clone_fields = [
         "vg",
@@ -302,16 +294,8 @@ class LogicalVolume(NetBoxModel):
         "path",
         "fs",
         "description",
-        "storage_configuration"
     ]
 
-    #prerequisite_models = (
-    #    'netbox_storage.Filesystem',
-    #    'netbox_storage.VolumeGroup',
-    #    'netbox_storage.PhysicalVolume',
-    #    'netbox_storage.Drive',
-    #)
-
     def get_absolute_url(self):
         return reverse("plugins:netbox_storage:logicalvolume", kwargs={"pk": self.pk})
 
@@ -344,11 +328,6 @@ class LinuxVolume(NetBoxModel):
         max_length=255,
         blank=True,
     )
-    storage_configuration = models.ForeignKey(
-        StorageConfiguration,
-        on_delete=models.CASCADE,
-        related_name='storage_configuration_linux_volume',
-    )
 
     clone_fields = [
         "partition",
@@ -356,7 +335,6 @@ class LinuxVolume(NetBoxModel):
         "path",
         "fs",
         "description",
-        "storage_configuration"
     ]
 
     def get_absolute_url(self):
