@@ -1,8 +1,7 @@
-from extras.plugins import PluginTemplateExtension
-from itertools import chain
 import logging
 
-from netbox_storage.models import Drive, Partition, PhysicalVolume, LogicalVolume, VolumeGroup, LinuxVolume
+from extras.plugins import PluginTemplateExtension
+from netbox_storage.models import PhysicalVolume, LogicalVolume, LinuxVolume
 
 
 class LVMModel:
@@ -52,12 +51,11 @@ class RelatedDrives(PluginTemplateExtension):
             #                 lvm_model.partition_list = partition_list
 
         logger.warning(f'{lvm_list}')
-        linux_volume_list = []
-        linuxvolumes = LinuxVolume.objects.all()
+        LinuxVolume.objects.all()
         linux_volume_list = list(LinuxVolume.objects.all())
         logger.warning(f'linuxvolumes for {linux_volume_list}')
 
-        lv = LogicalVolume.objects.filter(storage_configuration=obj)
+        lv = LogicalVolume.objects.all()
 
         platform = obj.platform
         if platform is not None:
@@ -68,8 +66,6 @@ class RelatedDrives(PluginTemplateExtension):
                         # "volumes": volumes,
                         # "unmapped_drives": unmapped_drives,
                         "type": type(obj.platform),
-                        # "display_volume": display_volume
-                        #"physical_volumes": physical_volumes
                     },
                 )
             elif platform.name.lower().__contains__('linux'):
@@ -78,9 +74,6 @@ class RelatedDrives(PluginTemplateExtension):
                     extra_context={
                         "lvm_list": lvm_list,
                         "linux_volume_list": linux_volume_list,
-                        #"physical_volumes": physical_volumes,
-                        #"logical_volumes": logical_volumes,
-                        #"hd_partition_list": hd_partition_list
                     },
                 )
         else:
